# 一个主流图片压缩方案的自动化脚本（利用 tinify 实现）

### 实现三种图片输入的方式
* 用户指定需要压缩的图片文件名称
* 压缩当前文件夹下所有的 jpg/png/webp 图片（如果用户未指定图片）
* 将需要压缩的图片拖拽到我们的源文件上，从而实现自动压缩

### 支持图片的尺寸调整
* 输入宽度和高度（比如 600 800），表示按比例缩小图片，使其适合给定的尺寸
* 输入宽度（比如 600 0），表示按确定的宽度调整图片，高度适配
* 输入高度（比如 0 800），表示按确定的高度调整图片，宽度适配
* 如未输入宽度和高度，则表示按照原始分辨率来压缩图片

*** 需到tifiny官网申请API密匙 -> [传送门](https://tinify.cn/developers) ***